# pyeikonal

[![Actions Status](https://github.com/shakeflow/eikpy/actions/workflows/workflow.yml/badge.svg)](https://github.com/shakeflow/eikpy/actions)
[![coverage](https://codecov.io/gh/shakeflow/eikpy/branch/main/graph/badge.svg)](https://codecov.io/gh/shakeflow/eikpy)
[![docs](https://img.shields.io/badge/docs-stable-blue.svg)](https://shakeflow.github.io/eikpy/)
[![supported versions](https://img.shields.io/pypi/pyversions/eikpy.svg?label=python_versions)](https://pypi.python.org/pypi/eikpy)
[![docs](https://badge.fury.io/py/eikpy.svg)](https://badge.fury.io/py/eikpy)


Eikonal equation solver in Python.

## License
